==> cscec5b-rmat-api-3.0.1-20221021.093018-17-sources.jar: com/ejianc/business/rmat/vo/MaterialVO.java <==
package com.ejianc.business.rmat.vo;

import java.math.BigDecimal;
import java.util.List;


/**
 * 材料明细
 * 
 * @author generator
 * 
 */
public class MaterialVO {
    private static final long serialVersionUID = 1L;

    private String id; // 主键ID
    /** 合同信息 */
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String contractId; // 合同ID
    private String contractCode; // 合同编码
    private String contractName; // 合同名称
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private Long supplierId; // 供方主键
    private String supplierName; // 供方名称

    /** 物料信息 */
    private Long materialTypeId; // 物资分类主键
    private String materialTypeName; // 物资分类名称
    private Long materialId; // 物料主键
    private String materialCode; // 物料编码
    private String materialName; // 物料名称
    private String materialSourceId; // 物资来源主键
    private String spec; // 规格/型号
    private String unitId; // 档案单位id
    private String unitName; // 档案单位
    private BigDecimal num; // 数量
    private String realUnitId; // 实物单位id
    private String realUnitName; // 实物单位
    private BigDecimal realNum; // 实物数量
    private BigDecimal realTransScale; // 实物转换系数
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private BigDecimal rentNum; // 计租数量
    private BigDecimal rentTransScale; // 计租转换系数
    private Integer signRowType; // 合同签订方式,1-分类，2-材料
    private Boolean exitAdd;// 是否退场新增

    /** 在场信息 */
    private String useStatus; // 使用状态：0-停用，1-启用
    private BigDecimal checkedNum; // 已进场数量
    private BigDecimal startedNum; // 在场已启用数量
    private BigDecimal stopedNum; // 在场已停用数量
    private BigDecimal restitutedNum; // 已退赔数量
    private BigDecimal losedNum; // 已遗失数量
    private BigDecimal tempRestNum; // 未生效退赔数量
    private BigDecimal tempLoseNum; // 未生效遗失数量
    private BigDecimal numM;// 非台账可参照主数量
    private BigDecimal refNum; // 可参照数量

    private String useStatusName; // 使用状态：0-停用，1-启用

    private List<MaterialFlowVO> flowList;// 操作明细

    private List<MaterialFlowVO> beginList;// 期初

    private String parentId;// 父级主键
    private List<MaterialVO> children;// 子级

    public String getParentId() {
        return parentId;
    }

    public void setParentId(String parentId) {
        this.parentId = parentId;
    }

    public List<MaterialVO> getChildren() {
        return children;
    }

    public void setChildren(List<MaterialVO> children) {
        this.children = children;
    }

    public List<MaterialFlowVO> getBeginList() {
        return beginList;
    }

    public void setBeginList(List<MaterialFlowVO> beginList) {
        this.beginList = beginList;
    }

    public List<MaterialFlowVO> getFlowList() {
        return flowList;
    }

    public void setFlowList(List<MaterialFlowVO> flowList) {
        this.flowList = flowList;
    }

    public BigDecimal getNumM() {
        return numM;
    }

    public void setNumM(BigDecimal numM) {
        this.numM = numM;
    }

    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }

    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }

    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }

    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }

    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }

    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }

    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }

    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }

    public Integer getSignRowType() {
        return signRowType;
    }

    public void setSignRowType(Integer signRowType) {
        this.signRowType = signRowType;
    }

    public Boolean getExitAdd() {
        return exitAdd;
    }

    public void setExitAdd(Boolean exitAdd) {
        this.exitAdd = exitAdd;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public String getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(String useStatus) {
        this.useStatus = useStatus;
    }

    public BigDecimal getCheckedNum() {
        return checkedNum;
    }

    public void setCheckedNum(BigDecimal checkedNum) {
        this.checkedNum = checkedNum;
    }

    public BigDecimal getStartedNum() {
        return startedNum;
    }

    public void setStartedNum(BigDecimal startedNum) {
        this.startedNum = startedNum;
    }

    public BigDecimal getStopedNum() {
        return stopedNum;
    }

    public void setStopedNum(BigDecimal stopedNum) {
        this.stopedNum = stopedNum;
    }

    public BigDecimal getRestitutedNum() {
        return restitutedNum;
    }

    public void setRestitutedNum(BigDecimal restitutedNum) {
        this.restitutedNum = restitutedNum;
    }

    public BigDecimal getLosedNum() {
        return losedNum;
    }

    public void setLosedNum(BigDecimal losedNum) {
        this.losedNum = losedNum;
    }

    public BigDecimal getTempRestNum() {
        return tempRestNum;
    }

    public void setTempRestNum(BigDecimal tempRestNum) {
        this.tempRestNum = tempRestNum;
    }

    public BigDecimal getTempLoseNum() {
        return tempLoseNum;
    }

    public void setTempLoseNum(BigDecimal tempLoseNum) {
        this.tempLoseNum = tempLoseNum;
    }

    public BigDecimal getRefNum() {
        return refNum;
    }

    public void setRefNum(BigDecimal refNum) {
        this.refNum = refNum;
    }

    public String getUseStatusName() {
        return useStatusName;
    }

    public void setUseStatusName(String useStatusName) {
        this.useStatusName = useStatusName;
    }
}

==> cscec5b-rmat-api-3.0.1-20221228.030533-115-sources.jar: com/ejianc/business/rmat/vo/MaterialVO.java <==
package com.ejianc.business.rmat.vo;

import java.math.BigDecimal;
import java.util.List;


/**
 * 材料明细
 * 
 * @author generator
 * 
 */
public class MaterialVO {
    private static final long serialVersionUID = 1L;

    private String id; // 主键ID
    /** 合同信息 */
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String contractId; // 合同ID
    private String contractCode; // 合同编码
    private String contractName; // 合同名称
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private Long supplierId; // 供方主键
    private String supplierName; // 供方名称
    private String infoId; // 合同清单主键

    /** 物料信息 */
    private Long materialTypeId; // 物资分类主键
    private String materialTypeName; // 物资分类名称
    private Long materialId; // 物料主键
    private String materialCode; // 物料编码
    private String materialName; // 物料名称
    private String materialSourceId; // 物资来源主键
    private String spec; // 规格/型号
    private String unitId; // 档案单位id
    private String unitName; // 档案单位
    private BigDecimal num; // 数量
    private String realUnitId; // 实物单位id
    private String realUnitName; // 实物单位
    private BigDecimal realNum; // 实物数量
    private BigDecimal realTransScale; // 实物转换系数
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private BigDecimal rentNum; // 计租数量
    private BigDecimal rentTransScale; // 计租转换系数
    private Integer signRowType; // 合同签订方式,1-分类，2-材料
    private Boolean exitAdd;// 是否退场新增

    /** 在场信息 */
    private String useStatus; // 使用状态：0-停用，1-启用
    private BigDecimal checkedNum; // 已进场数量
    private BigDecimal startedNum; // 在场已启用数量
    private BigDecimal stopedNum; // 在场已停用数量
    private BigDecimal restitutedNum; // 已退赔数量
    private BigDecimal losedNum; // 已遗失数量
    private BigDecimal tempRestNum; // 未生效退赔数量
    private BigDecimal tempLoseNum; // 未生效遗失数量
    private BigDecimal numM;// 非台账可参照主数量
    private BigDecimal refNum; // 可参照数量

    private String useStatusName; // 使用状态：0-停用，1-启用

    private List<MaterialFlowVO> flowList;// 操作明细

    private List<MaterialFlowVO> beginList;// 期初

    private String parentId;// 父级主键
    private List<MaterialVO> children;// 子级

    public String getParentId() {
        return parentId;
    }

    public void setParentId(String parentId) {
        this.parentId = parentId;
    }

    public List<MaterialVO> getChildren() {
        return children;
    }

    public void setChildren(List<MaterialVO> children) {
        this.children = children;
    }

    public List<MaterialFlowVO> getBeginList() {
        return beginList;
    }

    public void setBeginList(List<MaterialFlowVO> beginList) {
        this.beginList = beginList;
    }

    public List<MaterialFlowVO> getFlowList() {
        return flowList;
    }

    public void setFlowList(List<MaterialFlowVO> flowList) {
        this.flowList = flowList;
    }

    public BigDecimal getNumM() {
        return numM;
    }

    public void setNumM(BigDecimal numM) {
        this.numM = numM;
    }

    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }

    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }

    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }

    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }

    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }

    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }

    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }

    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }

    public Integer getSignRowType() {
        return signRowType;
    }

    public void setSignRowType(Integer signRowType) {
        this.signRowType = signRowType;
    }

    public Boolean getExitAdd() {
        return exitAdd;
    }

    public void setExitAdd(Boolean exitAdd) {
        this.exitAdd = exitAdd;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getInfoId() {
        return infoId;
    }

    public void setInfoId(String infoId) {
        this.infoId = infoId;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public String getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(String useStatus) {
        this.useStatus = useStatus;
    }

    public BigDecimal getCheckedNum() {
        return checkedNum;
    }

    public void setCheckedNum(BigDecimal checkedNum) {
        this.checkedNum = checkedNum;
    }

    public BigDecimal getStartedNum() {
        return startedNum;
    }

    public void setStartedNum(BigDecimal startedNum) {
        this.startedNum = startedNum;
    }

    public BigDecimal getStopedNum() {
        return stopedNum;
    }

    public void setStopedNum(BigDecimal stopedNum) {
        this.stopedNum = stopedNum;
    }

    public BigDecimal getRestitutedNum() {
        return restitutedNum;
    }

    public void setRestitutedNum(BigDecimal restitutedNum) {
        this.restitutedNum = restitutedNum;
    }

    public BigDecimal getLosedNum() {
        return losedNum;
    }

    public void setLosedNum(BigDecimal losedNum) {
        this.losedNum = losedNum;
    }

    public BigDecimal getTempRestNum() {
        return tempRestNum;
    }

    public void setTempRestNum(BigDecimal tempRestNum) {
        this.tempRestNum = tempRestNum;
    }

    public BigDecimal getTempLoseNum() {
        return tempLoseNum;
    }

    public void setTempLoseNum(BigDecimal tempLoseNum) {
        this.tempLoseNum = tempLoseNum;
    }

    public BigDecimal getRefNum() {
        return refNum;
    }

    public void setRefNum(BigDecimal refNum) {
        this.refNum = refNum;
    }

    public String getUseStatusName() {
        return useStatusName;
    }

    public void setUseStatusName(String useStatusName) {
        this.useStatusName = useStatusName;
    }
}
